pro coadd, files=files, file_out=file_out, hipe10=hipe10

n_files = n_elements(files)
crval1s = fltarr(n_files)
crval2s = fltarr(n_files)
ra_mins = fltarr(n_files)
ra_maxs = fltarr(n_files)
dec_mins = fltarr(n_files)
dec_maxs = fltarr(n_files)

if keyword_set(hipe10) then n_cov = 2 else n_cov = 3

for i=0,n_files-1 do begin

  im = mrdfits(files(i),1,hh)
  cov = mrdfits(files(i),n_cov,hc)
  if i eq 0 then h00 = hh ;## we keep the header of the first file

  n1 = fxpar(hh,'NAXIS1')
  n2 = fxpar(hh,'NAXIS2')
  gxy = gridxy(n1,n2)
  
  xyad, hh, gxy(*,*,0), gxy(*,*,1), ra, dec
  ra_mins(i) = min(ra)
  ra_maxs(i) = max(ra)
  dec_mins(i) = min(dec)
  dec_maxs(i) = max(dec)
  
  crval1s(i) = fxpar(hh,'CRVAL1')
  crval2s(i) = fxpar(hh,'CRVAL2')
  
endfor

min_ra = min(ra_mins)
max_ra = max(ra_maxs)
min_dec = min(dec_mins)
max_dec = max(dec_maxs)

crval1 = biweight_mean(crval1s)
crval2 = biweight_mean(crval2s)

cdelt1 = fxpar(h00,'CDELT1')
cdelt2 = fxpar(h00,'CDELT2')
ctype1 = fxpar(h00,'CTYPE1')
ctype2 = fxpar(h00,'CTYPE2')

n1_new = long(2.*max(abs(crval1-[min_ra,max_ra]))/abs(cdelt1)+1)
n2_new = long(2.*max(abs(crval2-[min_dec,max_dec]))/abs(cdelt2)+1)

print, 'New file size: ', n1_new, n2_new


im00 = fltarr(n1_new,n2_new)
cov00 = fltarr(n1_new,n2_new)

mkhdr, hh_new, im00
fxaddpar, hh_new, 'CTYPE1', ctype1
fxaddpar, hh_new, 'CTYPE2', ctype2
fxaddpar, hh_new, 'CDELT1', cdelt1
fxaddpar, hh_new, 'CDELT2', cdelt2
fxaddpar, hh_new, 'CRVAL1', crval1
fxaddpar, hh_new, 'CRVAL2', crval2
fxaddpar, hh_new, 'CRPIX1', n1_new/2.
fxaddpar, hh_new, 'CRPIX2', n2_new/2.

im0 = fltarr(n1_new, n2_new, n_files)
cov0 = fltarr(n1_new, n2_new, n_files)

for i=0,n_files-1 do begin
  
  im = mrdfits(files(i),1,hh)
  cov = mrdfits(files(i),n_cov,hc)
  
  hastrom, im, hh, imc, hhc, hh_new
  print, '!!!'
  help, cov
  hastrom, cov, hh, covc, hhc, hh_new
  
  im0(*,*,i) = imc
  cov0(*,*,i) = covc
  
endfor


for i=0,n1_new-1 do begin
  for j=0,n2_new-1 do begin
  
    im00(i,j) = total(im0(i,j,*)*cov0(i,j,*))/total(cov0(i,j,*))
    cov00(i,j) = total(cov0(i,j,*))
  
  endfor 
endfor  

data = fltarr(n1_new,n2_new,2)
data(*,*,0) = im00
data(*,*,1) = cov00

writefits, file_out, data, hh_new

end