pro derive_ddiff_map, file1=file1, file2=file2, im_diff=im_diff $
   , dir_out=dir_out, shift_ra=shift_ra, shift_dec=shift_dec, read_fits=read_fits $
   , cov_diff=cov_diff, center_1 = center_1, center_2 = center_2

;####### !! SHIFT_RA and SHIFT_DEC are assumed to be in ARCSECS! ########

dir0 = dir_out

if keyword_set(read_fits) then begin
  
  data1 = readfits(file1,h1)
  image_1 = data1(*,*,0)
  coverage_1 = data1(*,*,1)
  
  data2 = readfits(file2,h2)
  image_2 = data2(*,*,0)
  coverage_2 = data2(*,*,1)
  
  image_diff = readfits(im_diff,hdiff)
  coverage_diff = readfits(cov_diff,hdiffcov)
  
endif else begin

  image_1 = mrdfits(file1,1,h1)
  coverage_1 = mrdfits(file1,3)
  image_2 = mrdfits(file2,1,h2)
  coverage_2 = mrdfits(file2,3)
  image_diff = readfits(im_diff,hdiff)
  coverage_diff = readfits(cov_diff,hdiffcov)
  
endelse

dra = fxpar(hdiff,'CDELT1')
ddec = fxpar(hdiff,'CDELT2')

print, 3600.*[dra, ddec]

n1_image1 = fxpar(h1,'NAXIS1')
n2_image1 = fxpar(h1,'NAXIS2')

n1_image2 = fxpar(h2,'NAXIS1')
n2_image2 = fxpar(h2,'NAXIS2')

n1_diff = fxpar(hdiff,'NAXIS1')
n2_diff = fxpar(hdiff,'NAXIS2')

;----------------------------------------------------------------------
; What are the coordinates of the image centers?
;----------------------------------------------------------------------

if not keyword_set(center_1) then begin

  xyad, h1, n1_image1/2., n2_image1/2., ra_center_1, dec_center_1
  xyad, h2, n1_image2/2., n2_image2/2., ra_center_2, dec_center_2
  xyad, hdiff, n1_diff/2., n2_diff/2., ra_center_diff, dec_center_diff

  print, 'Visit1: ', [ra_center_1, dec_center_1]
  print, 'Visit2: ', [ra_center_2, dec_center_2]
  print, 'Diff: ', [ra_center_diff, dec_center_diff]
  
endif else begin
  
  ra_center_1 = center_1(0)
  dec_center_1 = center_1(1)
  ra_center_2 = center_2(0)
  dec_center_2 = center_2(1)
  
endelse


;----- so this is the offset anyway ------
dd_dec = (dec_center_1 - dec_center_2)
dd_ra = (ra_center_1 - ra_center_2)


;;; = dec_center_1 - dec_center_2
;;; dd_ra = (ra_center_1 - ra_center_2)/cos(dec_center_diff*!pi/180.)
;;;print, cos(dec_center_diff*!pi/180.)

print, 'Offsets: ', [dd_ra, dd_dec]*3600.

;---- we need to create the shifted image -----

hdiff2 = hdiff
cr1_0 = fxpar(hdiff,'CRVAL1')
cr2_0 = fxpar(hdiff,'CRVAL2')  
fxaddpar, hdiff2, 'CRVAL1', cr1_0 + dd_ra + shift_ra/3600./cos(dec_center_1*!pi/180.)
fxaddpar, hdiff2, 'CRVAL2', cr2_0 + dd_dec + shift_dec/3600.

shift_ra_str = strcompress(string(shift_ra, format='(F5.1)'),/remo)
shift_dec_str = strcompress(string(shift_dec, format='(F5.1)'),/remo)

image_diff_2 = -1.0*image_diff

;---- creating the double-differential image -----

h_ddiff = hdiff
fxaddpar, h_ddiff, 'CRVAL1', cr1_0 + dd_ra/2.
fxaddpar, h_ddiff, 'CRVAL2', cr2_0 + dd_dec/2.

hastrom, image_diff, hdiff, image_diff_mod, hdiff_mod, h_ddiff
hastrom, image_diff_2, hdiff2, image_diff_2_mod, hdiff2_mod, h_ddiff

image_ddiff = image_diff_mod + image_diff_2_mod

filename_ddiff = dir0 + '/ddiff_im_' + shift_ra_str + '_' + shift_dec_str + '.fits' 
writefits, filename_ddiff, image_ddiff, h_ddiff
 
end

;---------------------


;===================================================

pro create_ddiff_xxx, band=band, object=object $
  , shifts = shifts, step=step

if not keyword_set(step) then step = 0.5

ra_shifts = step*(findgen(11)-5.)
dec_shifts = step*(findgen(11)-5.)

str_n = strcompress(string(shifts(0)),/remo)
str_m = strcompress(string(shifts(1)),/remo)

print, '>>> ', object, band

res0 = get_old_coordinates( dir0 = './' $;, /read_fits $
      ,file1 =   object + '_visit1_blue.fits' $
      ,file2 =   object + '_visit2_blue.fits')
      
  for ira = 0,n_elements(ra_shifts)-1 do begin
    for idec = 0,n_elements(dec_shifts)-1 do begin
    
      dir0_ = object+'_'+band+'_images/'
     
      file1_ =   object + '_visit1_'+band+'.fits'
      file2_ =   object + '_visit2_'+band+'.fits'
     ;  file_diff_ = dir0_ + '/diff_im_'+str_n+'_'+str_m+'.fits' 
     ;    print, file_diff_
      res = derive_ddiff_map_III($
          file1 = file1_ $
        , file2 = file2_ $
        , im_diff= object +'_'+band+'_images/diff_im_'+str_n+'_'+str_m+'_R31.fits' $
        , cov_diff = object +'_'+band+'_images/diff_cov_'+str_n+'_'+str_m+'_R31.fits' $
        , dir0= object  + '_'+band+'_images/' $
        , shift_ra=ra_shifts(ira), shift_dec=dec_shifts(idec) $
        , center_1 = res0(*,0), center_2 = res0(*,1))
      

    endfor
  endfor  
  

end
;-------

pro create_ddiff_maps_2002tc302

bands = ['blue','green','red']
objects = ['2002tc302' ]
shift_array = [[5,5]]

for iband=0,n_elements(bands)-1 do begin
  for iobj=0,n_elements(objects)-1 do begin
    
      create_ddiff_xxx, band=bands(iband) $
         , object=objects(iobj), shifts=shift_array(*,iobj), step=1.0  
  
  endfor
endfor  


end

