pro create_shifted_maps, file1=file1, file2=file2 $
    , dir0=dir0, read_fits=read_fits, dra=dra, ddec=ddec

;## Creates a set of shifted images from the 2nd visit images
;## these are stored in separate folders

if keyword_set(read_fits) then begin

  data1 = readfits(file1,h1)
  image_1 = data1(*,*,0)
  coverage_1 = data1(*,*,0)
  data2 = readfits(file2,h2)
  image_2 = data2(*,*,0)
  coverage_2 = data2(*,*,1)
  
endif else begin

  image_1 = mrdfits(file1,1,h1)
  coverage_1 = mrdfits(file1,3)
  image_2 = mrdfits(file2,1,h2)
  coverage_2 = mrdfits(file2,3)

endelse

dra = fxpar(h1,'CDELT1')
ddec = fxpar(h1,'CDELT2')

print, 3600.*[dra, ddec]

n1_image1 = fxpar(h1,'NAXIS1')
n2_image1 = fxpar(h1,'NAXIS2')

n1_image2 = fxpar(h2,'NAXIS1')
n2_image2 = fxpar(h2,'NAXIS2')

;----------------------------------------------------------------------
; What are the coordinates of the image centers?
;----------------------------------------------------------------------

xyad, h1, n1_image1/2., n2_image1/2., ra_center_1, dec_center_1
xyad, h2, n1_image2/2., n2_image2/2., ra_center_2, dec_center_2

print, [ra_center_1, dec_center_1]
print, [ra_center_2, dec_center_2]

dd_ra = ra_center_1 - ra_center_2
dd_dec = dec_center_1 - dec_center_2

print, [dd_ra, dd_dec]*3600.

h2m = h2
crpix1_0 = fxpar(h2,'CRPIX1')
crpix2_0 = fxpar(h2,'CRPIX2')
crval1_0 = fxpar(h2,'CRVAL1')
crval2_0 = fxpar(h2,'CRVAL2')

if not keyword_set(dra) then dx = (findgen(11)-5.) else dx=dra
if not keyword_set(ddec) then dy = (findgen(11)-5.) else dy=ddec

for i=0,n_elements(dx)-1 do begin
  for j=0,n_elements(dy)-1 do begin

    fxaddpar, h2m, 'CRVAL1', crval1_0 + dx(i)/3600.
    fxaddpar, h2m, 'CRVAL2', crval2_0 + dy(j)/3600.
    fxaddpar, h2m, 'SHIFTRA', dx(i)
    fxaddpar, h2m, 'SHIFTDEC', dy(j)
    i_str = strcompress(string(i,format='(I)'),/remo)
    j_str = strcompress(string(j,format='(I)'),/remo)
    
    ;print, i_str, ',', j_str
    
    writefits, dir0+'Visit2_im_'+i_str+'_'+j_str+'_crval.fits' $
       , image_2, h2m
    
    writefits, dir0+'Visit2_cov_'+i_str+'_'+j_str+'_crval.fits' $
       , coverage_2, h2m
  
  endfor
endfor

return

end

;########################


pro derive_shifted_maps_salacia_red

dir0_name = 'salacia_red_images' 
spawn, 'mkdir ' + dir0_name

file1_ = 'salacia_visit1_red.fits'
file2_ = 'salacia_visit2_red.fits'
dir0_ = dir0_name + '/'

derive_shifted_maps_crval, file1=file1_, file2=file2_, dir0=dir0_, /read_fits

end
;########################


pro derive_shifted_maps_salacia_blue

dir0_name = 'salacia_blue_images' 
spawn, 'mkdir ' + dir0_name

file1_ = 'salacia_visit1_blue.fits'
file2_ = 'salacia_visit2_blue.fits'
dir0_ = dir0_name + '/'

derive_shifted_maps_crval, file1=file1_, file2=file2_, dir0=dir0_, /read_fits

end
;########################


pro derive_shifted_maps_salacia_green

dir0_name = 'salacia_green_images' 
spawn, 'mkdir ' + dir0_name

file1_ = 'salacia_visit1_green.fits'
file2_ = 'salacia_visit2_green.fits'
dir0_ = dir0_name + '/'

derive_shifted_maps_crval, file1=file1_, file2=file2_, dir0=dir0_, /read_fits

end

;#########################

pro create_shifted_maps_all_tc302_new

;bands = ['blue','red']
;objects = ['1994TB', '1998sm165', '1999cd158', '1999de9', '2000cn105', '2001QG298' $
;        , '2001yh140', '2002gp32', '2002tc302', '2002wc19', '2003fb128' $
;        , '2003qw90', '2003uy117', '2003uz413', '2003wu172', '2005rs43', 'Ixion' ]
;
;### This is for the green only ####
;bands = ['green']
 ;       objects = ['1994TB', '1998sm165', '1999cd158', '1999de9', '2000cn105', '2001QG298' $
 ;       , '2001yh140', '2002gp32', '2002tc302', '2002wc19', '2003fb128' $
 ;       , '2003qw90', '2003uz413', '2003wu172', '2005rs43', 'Ixion' ]

;bands = ['blue']
;bands = ['green']
bands = ['red']
objects = ['2002tc302']
        
for iobj = 0,n_elements(objects)-1 do begin
   
   object = objects(iobj)
   
   for iband = 0,n_elements(bands)-1 do begin

      band = bands(iband)

      dir0_name = object + '_' + band + '_images' 
      spawn, 'mkdir ' + dir0_name

      file1_ =  object + '_visit1_' + band + '.fits'
      file2_ =  object + '_visit2_' + band + '.fits'
      dir0_ = dir0_name + '/'

      derive_shifted_maps_crval, file1=file1_, file2=file2_ $
          , dir0=dir0_;, /read_fits


   endfor

endfor   

end