pro create_supersky_map, file1=file1, file2=file2, superksky_file=supersky_file $
  , read_fits=read_fits, hipe10=hipe10, mosaic=mosaic

;supersky_file = 'supersky_red_2.fits'

;dir0 = '~/Astro/TNOsAreCool/Reprocessing3/FullTNOSample-R2A/'
;object = '2004gv9'
;band = 'red'

if keyword_set(mosaic) then extcov = 7 else extcov = 2
if keyword_set(hipe10) then extcov = 2

if keyword_set() then begin
   data = readfits(file1,h1)
   im1 = data(*,*,0)
   cov1 = data(*,*,1)
   data = readfits(file2,h2)
   im2 = data(*,*,0)
   cov2 = data(*,*,1) 
endif else begin
  im1 = mrdfits(file1, 1, h1)
  cov1 = mrdfits(file1, 7, h1c)
  im2 = mrdfits(file2, 1, h2)
  cov2 = mrdfits(file2, 7, h2c)
endelse

nn = 301
supersky = fltarr(nn,nn)

n1_1 = fxpar(h1,'NAXIS1')
n2_1 = fxpar(h1,'NAXIS2')
n1_2 = fxpar(h2,'NAXIS1')
n2_2 = fxpar(h2,'NAXIS2')

xyad, h1, n1_1/2., n2_1/2., ra_center_1, dec_center_1
xyad, h2, n1_2/2., n2_2/2., ra_center_2, dec_center_2

ra_center = 0.5*(ra_center_1 + ra_center_2)
dec_center = 0.5*(dec_center_1 + dec_center_2)

;print, 'Common image center: ', ra_center, dec_center

dra = (ra_center_1 - ra_center_2)
ddec = (dec_center_1 - dec_center_2)
decm = 0.5*(dec_center_1 + dec_center_2)

;print, 'Distance of the image centers in RA/DEC (arcsec): ', 3600.*[dra, ddec]
dist0 = acos( sin(dec_center_1*!pi/180.)*sin(dec_center_2*!pi/180.) $ 
  + cos(dec_center_1*!pi/180.)*cos(dec_center_2*!pi/180.)*cos(dra*!pi/180.) )
;print, 'Spherical distance of the image centers (arcsec): ', dist0*180./!pi*3600.

;------------------------------------------------------------
; "r_mask" is the radius we are using for the masks 
;------------------------------------------------------------

r_mask = dist0*180./!pi*0.45

;------------------------------------------------------------
; Constructing the masks from the common-frame images
;------------------------------------------------------------

gxy1 = gridxy(n1_1,n2_1)
gxy2 = gridxy(n1_2,n2_2)

xyad, h1, gxy1(*,*,0), gxy1(*,*,1), ra1, dec1
xyad, h1, gxy1(*,*,0), gxy1(*,*,1), ra2, dec2

d1 = ra1*0.0
d2 = ra2*0.0

d1 = 180./!pi*acos( sin(dec1*!pi/180.)*sin(dec_center_1*!pi/180.) $ 
    + cos(dec1*!pi/180.)*cos(dec_center_1*!pi/180.)*cos((ra_center_1-ra1)*!pi/180.) )

ii1 = where(d1 lt r_mask)

d2 = 180./!pi*acos( sin(dec2*!pi/180.)*sin(dec_center_2*!pi/180.) $ 
    + cos(dec2*!pi/180.)*cos(dec_center_2*!pi/180.)*cos((ra_center_2-ra2)*!pi/180.) )

ii2 = where(d2 lt r_mask)

;-------------------------------------------------------------
; Producing the masked images
;-------------------------------------------------------------

im1_masked = im1
im2_masked = im2 
h1_masked = h1
h2_masked = h2

;--------------------------------------------------------------
; Supersky-1 (in the im1 system, im2 transformed)
;--------------------------------------------------------------

supersky1 = im1

hastrom, im1, h1, im1_masked, h1_masked, h1
hastrom, im2, h2, im2_masked, h2_masked, h1

im1_masked(ii1) = -1.*sqrt(-1)
im2_masked(ii2) = -1.*sqrt(-1)

for i=0,n1_1-1 do begin
  for j=0,n2_1-1 do begin
     supersky1(i,j) = biweight_mean([im1_masked(i,j),im2_masked(i,j)]) 
  endfor
endfor  

writefits, supersky_file, supersky1, h1

end