function implanted_source_noise, fb=fb, fcov=fcov, coverage_limit=coverage_limit $
  , threshold=threshold, gradius=gradius, flux_source=flux_source $
  , scale_0 = scale_0, ddiff=ddiff, dir_psf=dir_psf, band=band $
  , mycoverage=mycoverage, datacube=datacube, hipe_mosaic=hipe_mosaic
  
if not keyword_set(coverage_limit) then begin
  coverage_limit = [0.25,0.9]
  flag = 'def'
endif else begin
  s1 = strcompress(string(coverage_limit(0),format='(F5.2)'),/remo)
  s2 = strcompress(string(coverage_limit(1),format='(F5.2)'),/remo)
  flag = s1+'-'+s2
endelse
if not keyword_set(threshold) then threshold = 10.
;if not keyword_set(dsize) then dsize0 = 80
if not keyword_set(gradius) then gradius = 25
if not keyword_set(flux_source) then flux_source = 0.3
if not keyword_set(sigma_gauss) then sigma_gauss = 5.
if not keyword_set(scale_0) then scale_0 = 1
;if not keyword_set(cradius) then cradius = 50

if keyword_set(mycoverage) then begin
  image = readfits(fb,h)
  coverage = readfits(fcov,h)
endif

if keyword_set(ddiff) then begin
    image = mrdfits(fb,1,h)
    coverage = mrdfits(fcov,1)  
endif 

if keyword_set(hipe_mosaic) then begin
    image = mrdfits(fb,1,h)
    coverage = mrdfits(fb,7)
endif

if keyword_set(datacube) then begin
  data = readfits(fb,h)
  image = data(*,*,0)
  coverage = data(*,*,1)
endif

ii = where(coverage*1.0 ne coverage)
if ii(0) ne -1 then coverage(ii) = 0.0
rel_coverage = coverage/max(coverage)  
set_plot,'x'
plot, coverage
print, max(coverage)

ii = where((rel_coverage le coverage_limit(0)) or (rel_coverage ge coverage_limit(1)) $
                , cc, comp=jj)
image_c = 0
image_c = image*0.0+1.
if ii(0) ne -1 then image_c(ii) = 0

ss = size(image)
n1 = ss(1)
n2 = ss(2)
xx = fltarr(n1,n2)
yy = fltarr(n1,n2)
for i=0,n1-1 do begin
  for j=0,n2-1 do begin
    xx(i,j) = i
    yy(i,j) = j
  endfor
endfor  

if not keyword_set(dir_psf) then DIR_PSF = '/Users/pkisscs/MyTools/PSFs/'
if band eq 'blue' then begin
  psf_image = 'combined_psf_blue_1.10.fits'
  ap_corr_5 = 0.604
  renorm_corr = 1.0913
  ;renorm_corr = 1.
endif
if band eq 'green' then begin
  psf_image = 'combined_psf_green_1.40.fits'
  ap_corr_5 = 0.63
  renorm_corr = 1.6313
  ;renorm_corr = 1.
endif
if band eq 'red' then begin
  psf_image = 'combined_psf_red_2.10.fits'
  ap_corr_5 = 0.63
  renorm_corr = 3.7638
  ;renorm_corr = 1.
endif
  
psf = readfits(DIR_PSF+psf_image,h_psf)
ng = 15

isource = renorm_corr*cut_central_map(psf,ng)
isource = flux_source*isource
ss = size(isource)

x1 = ss(1)/2
y1 = ss(2)/2
d = image*0.0

for i=0,n1-1 do begin
  for j=0,n2-1 do begin
    d(i,j) = sqrt((x1-i)^2 + (y1-j)^2)
  endfor
endfor


;igauss = fltarr(2*ng+1,2*ng+1)
;xxg = fltarr(2*ng+1,2*ng+1)
;yyg = fltarr(2*ng+1,2*ng+1)
;for i=0,2*ng do begin
;  for j=0,2*ng do begin
;     igauss(i,j) = exp(-1*((i-ng)^2+(j-ngbn)^2)/(2.*sigma_gauss))
;  endfor
;endfor  
;igauss = igauss/total(igauss)*flux_source

igauss = isource

x1 = n1/2
y1 = n2/2
d = image*0.0

for i=0,n1-1 do begin
  for j=0,n2-1 do begin
    d(i,j) = sqrt((x1-i)^2 + (y1-j)^2)
  endfor
endfor

ii = where(d lt 20.)
image_c(ii) = 0

writefits, fb+'_image_c_'+flag+'.fits', image_c

;--- Generating the random gaussian sources now / photometry of a 10mJy source ----

if not keyword_set(nprobe) then nprobe = 200
fl_gauss = findgen(nprobe,7)
image2 = image
ii = where(image ne image)
if ii(0) ne -1 then image2(ii) = 0

;tvscl, image2*image_c

writefits, fb+'_maskedimage'+flag+'.fits', image2*image_c

set_plot, 'ps'
device, file=fb+'_rphot2.ps', /color, /encapsulated
loadct ,13
i = 0
while i lt nprobe do begin 
  
  accept = 0 
  while accept eq 0 do begin
    
    xg1 = gradius + long(randomu(seed)*(n1-2*gradius))
    yg1 = gradius + long(randomu(seed)*(n2-2*gradius))
    d1 = sqrt((xx-xg1)^2+(yy-yg1)^2)
    ii = where(d1 lt gradius,cc)
    c_count = total(image_c(ii))
    ;print, i, cc, gradius^2*!pi
    if c_count gt gradius^2*!pi*0.9 then accept=1 else accept=0    
  endwhile
  
  im1 = image(xg1-ng:xg1+ng,yg1-ng:yg1+ng) + igauss
  print, '>>>>>>  ', i, total(im1), flux_source
  ;tvscl, rebin(im1, 5*(2*ng+1), 5*(2.*ng+1), /sample)
  sky, im1, skymod1, skysig1 ,/SILENT, /MEANBACK, /NAN
  find, im1, xc, yc, flux, sharp, round, threshold * skysig1, 5 $
     , [-1.0,1.0], [0.2,1.0], /silent
  ;print, xc, yc
  if (xc(0) le 1 or yc(0) le 1 or xc(0) gt (2*ng-1) or yc(0) gt (2*ng-1)) then begin    
      print, '>>>> Failed to find the source, retrying...'
  endif else begin  
      print, "Performing photometry at ", xc, yc
      maper, im1, xc, yc, flg, flerrg, sky1g, skyerr1g, 1 $
      , [1,2,3,4,5,6,7]*scale_0, [10,15]*scale_0, [-1000,1000], /flux, /onlyskyerr
      print, size(flg)
      fl_gauss(i,*) = flg(*,0)
      i = i + 1
  endelse

endwhile


iring = 4
print, '====> ', median(fl_gauss(*,iring))/ap_corr_5 $
               , sigma(fl_gauss(*,iring))/ap_corr_5
print, '====> ', biweight_mean(fl_gauss(*,iring))/ap_corr_5 $
               , stdev(fl_gauss(*,iring))/ap_corr_5
               
bin_size = 0.001
h = 0
h = histogram(fl_gauss(*,iring),binsize=bin_size, min=0, max=2.*flux_source)
fluxbins = findgen(n_elements(h))*bin_size
fitted_gauss = gaussfit(fluxbins, h, gauss_params)
print, '>>> Parameters of the Gaussian: ', gauss_params

plot, fluxbins, h, psym=10
oplot, fluxbins, fitted_gauss, psym=-5, color=255

device, /close
set_plot, 'x'

save, file=fb + '_rphot2.sav', fl_gauss

return, [robust_sigma(fl_gauss(*,iring))]

end

;----------------------
pro run1

object = '2012DR30'
band_ = 'red'
;dir0 = object + '_' + band_ + '_images/'
dir0 = './'
fb_ = dir0 + 'coadd_2012DR30_visit2_red.fits' 
;fcov_ = dir0 + 'diff_cov_15_15.fits' 

a = psp_comb_psf_ii(fb = fb_, /datacube $
  , band=band_, coverage_limit=[0.25,0.95])
print, a*1000.
end

;----------------------
pro run_all_bands

object = '2007UK126'
;bands = ['blue','green','red']
bands = ['red']
;covlim_lower = [0.25,0.25,0.25]
covlim_lower = [0.2]
flux_unc = fltarr(n_elements(bands))

for i=0,n_elements(bands)-1 do begin
   dir0 = object + '_' + bands(i) + '_images/' 
   fb_ = dir0 + 'diff_im_15_15.fits'  
   fcov_ = dir0 + 'diff_cov_15_15.fits' 
  a = psp_comb_psf_ii(fb = fb_, fcov=fcov_, /mycov $
    , band=bands(i), coverage_limit=[covlim_lower(i),0.95])
  print, bands(i), a*1000.
  flux_unc(i) = a
endfor

print, bands, flux_unc

end

