function plot_shifted_contour_maps, dir0=dir0, dsize=dsize $
   , read_fits=read_fits, show=show, half=half, big=big $
   , center=center

if not keyword_set(dsize) then dsize = 10

;if not keyword_set(offset) then offset=[0.0,0.0]

set_plot, 'ps'
filec = dir0+'plot_shift_contour_maps.eps'
device, file=filec, /color, /encapsulated, xs=23, ys=20

;############################################# 

filename = dir0+'ddiff_im_0.0_0.0.fits'

if keyword_set(read_fits) then begin
  a = readfits(filename,h)
endif else begin
  a = mrdfits(filename,1,h)
endelse
  
n1 = fxpar(h,'NAXIS1')
n2 = fxpar(h,'NAXIS2')
a1 = a(n1/2-dsize:n1/2+dsize, n2/2-dsize:n2/2+dsize)
max_a1 = max(a1)*1000.    
;#############################################    

if keyword_set(half) then begin
     ra_string = ['-4.5', '-4.0', '-3.5', '-3.0', '-2.5', '-2.0' $
                , '-1.5', '-1.0', '-0.5', '0.0', '0.5', '1.0', '1.5' $
                , '2.0', '2.5', '3.0', '3.5', '4.0', '4.5']
endif else begin
     ra_string = ['-4.0', '-3.0', '-2.0', '-1.0', '0.0', '1.0' $
                 , '2.0', '3.0','4.0']

endelse 

if keyword_set(big) then $
    ra_string = ['-6.0', '-5.0', '-4.0', '-3.0', '-2.0', '-1.0', '0.0' $
                , '1.0', '2.0', '3.0', '4.0', '5.0', '6.0']

dec_string = ra_string
nn = n_elements(ra_string)

!p.multi = [0,nn,nn]
loadct, 4

mmax = 0
mmax_array = fltarr(nn,nn)
imax = 0
jmax = 0

for i=0,nn-1 do begin
  for j=0,nn-1 do begin
    
    filename = dir0+'ddiff_im_'+ra_string(i)+'_'+dec_string(j)+'.fits'
    
    if keyword_set(read_fits) then begin
        a = readfits(filename,h)
    endif else begin
        a = mrdfits(filename,1,h)
    endelse
    n1 = fxpar(h,'NAXIS1')
    n2 = fxpar(h,'NAXIS2')
    
    if not keyword_set(center) then center=[n1/2,n2/2]
    
    a1 = a(center(0)-dsize:center(0)+dsize $
              , center(1)-dsize:center(1)+dsize)*1000.

              
    contour, a1, /fill, levels=max_a1*(findgen(30))/29. $
      , title = ra_string(i)+' / '+dec_string(j), xst=5, yst=5, xmargin=2, ymargin=0
    contour, a1, levels = [1,2], /noerase, xst=5, yst=5
    mmax_array(i,j) = max(a1)
    if max(a1) gt mmax then begin
      mmax = max(a1)
      imax = i
      jmax = j
    endif  
  endfor
endfor

print, mmax, '  ', ra_string(imax), '  ', dec_string(jmax)
title_string = 'Maximum at (arcsec): ' + ra_string(imax) + ';  ' + dec_string(jmax)
device, /close

!p.multi = [0,1,1]

set_plot, 'ps'
file0 = dir0+'plot_shift_max_surface.ps'
device, file=file0, /color
loadct, 0
shade_surf, mmax_array, float(ra_string), float(dec_string), charsize=0.65 $
  , xtitle='R.A. offset (arcsec)', ytitle='DEC offset (arcsec)' $
  , ztitle='Intensity (mJy/pixel)', title=title_string

device, /close

if keyword_set(show) then spawn, 'gv '+ filec + '&'

print, offset
return, title_string



end