function run_phot0_task, image0=image0, band=band, threshold=threshold $
  , dsize0=dsize0, read_fits=read_fits, apap=apap, ss=ss, fwhm=fwhm $
  , eqat=eqat, centre=centre, random_ap=random_ap, invert=invert, scale=scale $
  , fixpos=fixpos

set_plot, 'x'

if not keyword_set(threshold) then treshold = 3.5
if not keyword_set(dsize0) then dsize0 = 25
if not keyword_set(fwhm) then fwhm=5.
if not keyword_set(scale) then scale=1.0
;### image0 = 'orcus_blue/ddiff_im_green.fits'

;###### Latest values are based on the evaluation on July 15, 2012 ######

if band eq 'blue' then begin
  ;appc4 = 0.6
  appc4 = 0.6*1.024
  ;appc5 = 0.675
  appc5 = 0.675*0.989
  appc3 = 0.461
  ap3 = 3.51
endif

if band eq 'green' then begin
  ;appc4 = 0.63
  appc4 = 0.63*1.016 
  ;appc5 = 0.718
  appc5 = 0.718*0.942
  appc3 = 0.489
  ap3 = 3.38
endif

if band eq 'red' then begin
  appc4 = 0.63
  ;appc4 = 0.63*0.933
  appc5 = 0.72
  ;appc5 = 0.72*0.891
  appc3 = 0.486
  ap3 = 3.54
endif

if keyword_set(read_fits) then begin
  im = readfits(image0,h)
endif else begin
  im = mrdfits(image0,1,h)
endelse
n1 = fxpar(h,'NAXIS1')
n2 = fxpar(h,'NAXIS2')

if keyword_set(invert) then im = -1.*im

if not keyword_set(centre) then begin
    im1 = im(n1/2-dsize0:n1/2+dsize0, n2/2-dsize0:n2/2+dsize0)
    shift_x = n1/2
    shift_y = n2/2
endif else begin
    im1 = im(centre(0)-dsize0:centre(0)+dsize0 $
           , centre(1)-dsize0:centre(1)+dsize0)        
    shift_x = centre(0)
    shift_y = centre(1)
endelse

if keyword_set(apap) then begin
  phot0, im1, xc, yc, fl, flerr, scale0=1, dsize=dsize0 $
           , threshold=threshold, apers = [ap3], fwhm=fwhm, setsky=ss
  f3 = fl/appc3
  print, '>>> Flux: ', f3
  zz = [f3]*2000.
endif else begin
  phot0, im1, xc, yc, fl, flerr, scale0=scale, dsize=dsize0 $
           , threshold=threshold, apers = [1,2,3,4,5,6], fwhm=fwhm 
  f4 = fl(4,*)/appc4
  f5 = fl(5,*)/appc5
  ef4 = flerr(4,*)/appc4
  ef5 = flerr(5,*)/appc5
  print, '>>> Flux: ', f4, f5, 0.5*(f4+f5)*1000.
  print, '>>> ErrFlux: ', ef4, ef5, 0.5*(ef4+ef5)*1000. 
  zz = [f4, f5, 0.5*(f4+f5)]*1000.
  ezz = [ef4, ef5, 0.5*(ef4+ef5)]*1000.
endelse 


;#### "random" apertures ####
if keyword_set(random_ap) then begin
  ra_fluxes = fltarr(3,3)
  xa = [3,3,3,25,25,47,47,47]
  ya = [3,25,47,3,47,3,25,47]
  ra_fluxes = fltarr(n_elements(xa))
  for i=0,n_elements(xa)-1 do begin
    ra_fluxes(i) = total(im1(xa(i)-3:xa(i)+3, ya(i)-3:ya(i)+3))
  endfor
  print, 'Flux error of the map:' $
    , robust_sigma(ra_fluxes)*1000., stdev(ra_fluxes)*1000. $
    , sigma(ra_fluxes)*1000.  
endif

xyad, h, xc+shift_x-dsize0, yc+shift_y-dsize0, ra, dec 

for i=0,n_elements(xc)-1 do begin
 print, '-----------------------------------------------'
 print, 'Photocenters: ', xc(i), yc(i)
;--- xyad, h, xc(i)+n1/2-dsize0, yc(i)+n2/2-dsize0, ra, dec 
 print, 'Coordinates: ', ra(i), dec(i)
 print, 'Fluxes: ', zz(0,i), zz(1,i), zz(2,i)
 print, 'ErrFluxes: ', ezz(0,i), ezz(1,i), ezz(2,i)
 
endfor
print, '-----------------------------------------------'

if keyword_set(eqat) then begin
  return, [ [transpose(zz(0,*))], [transpose(zz(1,*))] $
    ,[transpose(zz(2,*))],[ra],[dec]]
  ;return, [[ra],[dec]]
endif else begin
  return, zz
endelse 

end
